# AppPlatform

> see https://aka.ms/autorest

This is the AutoRest configuration file for AppPlatform.

---

## Getting Started

To build the SDK for AppPlatform, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the AppPlatform API.

``` yaml
openapi-type: arm
tag: package-preview-2021-06
```

### Suppression

``` yaml
directive:
  - suppress: EnumInsteadOfBoolean
    from: appplatform.json
    where: $.definitions.NameAvailability.properties.nameAvailable
    reason:  The boolean properties 'nameAvailable' is actually boolean value defined by Azure API spec
  - suppress: EnumInsteadOfBoolean
    from: appplatform.json
    where: $.definitions.Dimension.properties.toBeExportedForShoebox
    reason:  The boolean properties 'toBeExportedForShoebox' is defined by Geneva metrics
  - suppress: R3021
    from: appplatform.json
    reason:  The resource type name 'Spring' is a trademark so cannot be changed to be camel-case
    #where:
    #  - $.paths["/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/configServers/default"]
    #  - $.paths["/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/monitoringSettings/default"]
```


### Tag: package-preview-2021-06

These settings apply only when `--tag=package-preview-2021-06` is specified on the command line.

```yaml $(tag) == 'package-preview-2021-06'
input-file:
  - Microsoft.AppPlatform/preview/2021-06-01-preview/appplatform.json
```
### Tag: package-preview-2020-11

These settings apply only when `--tag=package-preview-2020-11` is specified on the command line.

``` yaml $(tag) == 'package-preview-2020-11'
input-file:
  - Microsoft.AppPlatform/preview/2020-11-01-preview/appplatform.json
```

### Tag: package-2020-07

These settings apply only when `--tag=package-2020-07` is specified on the command line.

``` yaml $(tag) == 'package-2020-07'
input-file:
  - Microsoft.AppPlatform/stable/2020-07-01/appplatform.json
```

### Tag: package-2019-05-01-preview

These settings apply only when `--tag=package-2019-05-01-preview` is specified on the command line.

``` yaml $(tag) == 'package-2019-05-01-preview'
input-file:
- Microsoft.AppPlatform/preview/2019-05-01-preview/appplatform.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-powershell
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_appplatform']
  - repo: azure-resource-manager-schemas
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Python

See configuration in [readme.python.md](./readme.python.md)

## Java

See configuration in [readme.java.md](./readme.java.md)

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "sdk" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  # last generated with AutoRest.0.17.3
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.AppPlatform
  output-folder: $(csharp-sdks-folder)/appplatform/Microsoft.Azure.Management.AppPlatform/src/Generated
  clear-output-folder: true
```
