# Blueprint

> see https://aka.ms/autorest

This is the AutoRest configuration file for Blueprint.

---
## Getting Started
To build the SDK for Blueprint, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information
These are the global settings for the Blueprint API.

``` yaml
title: BlueprintManagementClient
description: Blueprint Client
openapi-type: arm
tag: package-2018-11-preview
```


### Tag: package-2017-11-preview

These settings apply only when `--tag=package-2017-11-preview` is specified on the command line.

``` yaml $(tag) == 'package-2017-11-preview'
input-file:
- Microsoft.Blueprint/preview/2017-11-11-preview/blueprintDefinition.json
- Microsoft.Blueprint/preview/2017-11-11-preview/blueprintAssignment.json
```

### Tag: package-2018-11-preview

These settings apply only when `--tag=package-2018-11-preview` is specified on the command line.
 
``` yaml $(tag) == 'package-2018-11-preview'
input-file:
- Microsoft.Blueprint/preview/2018-11-01-preview/blueprintDefinition.json
- Microsoft.Blueprint/preview/2018-11-01-preview/blueprintAssignment.json
- Microsoft.Blueprint/preview/2018-11-01-preview/assignmentOperation.json
```

---
# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-python
  - repo: azure-resource-manager-schemas
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  namespace: Microsoft.Azure.Management.Blueprint
  payload-flattening-threshold: 1
  license-header: MICROSOFT_MIT_NO_VERSION
  output-folder: $(csharp-sdks-folder)/blueprint/Microsoft.Azure.Management.Blueprint/src/Generated
  clear-output-folder: true
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: true
  namespace: com.microsoft.azure.management.blueprint
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-blueprint
```


## Suppression


``` yaml
directive:
  - from: blueprintAssignment.json
    suppress: TrackedResourcePatchOperation 
    reason: Assignment is proxy resource.
  - from: blueprintDefinition.json
    suppress: UniqueResourcePaths
    where: $.paths
    reason: Microsoft.Management is a proxy resource provider
  - from: blueprintAssignment.json
    suppress: OperationsAPIImplementation
    where: $.paths
    reason: OperationsAPI for Microsoft.Management is out of scope.
  - from: blueprintDefinition.json
    suppress: OperationsAPIImplementation
    where: $.paths
    reason: OperationsAPI for Microsoft.Management is out of scope.    
  - from: assignmentOperation.json
    suppress: OperationsAPIImplementation
    where: $.paths
    reason: OperationsAPI for Microsoft.Management is out of scope.    
```



