# AzureMachineLearning

> see https://aka.ms/autorest

This is the AutoRest configuration file for AzureMachineLearning.

---
## Getting Started
To build the SDK for AzureMachineLearning, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the AzureMachineLearning API.

``` yaml
title: Azure Machine Learning Service
description: These APIs allow end users to manage Azure Machine Learning Services.
openapi-type: data-plane
tag: package-2019-09-preview
use-internal-constructors: true
add-credentials: true
```

### Suppression

``` yaml
directive:
  - suppress: AvoidNestedProperties
    reason: Client defined properties dictionaries should not be flattened.
  - suppress: GuidUsage
    reason: Existing properties; cannot change without breaking API
  - suppress: DeleteMustNotHaveRequestBody
    reason: Existing API for batch deletion
  - suppress: LROStatusCodesReturnTypeSchema
    reason: Not a Long Running Operation
  - from: hyperdrive.json
    suppress: DefinitionsPropertiesNamesCamelCase
    reason: Existing service; would be a breaking change
```

### Tag: package-2019-09-preview

These settings apply only when `--tag=package-2019-09-preview` is specified on the command line.

```yaml $(tag) == 'package-2019-09-preview'
input-file:
  - Microsoft.MachineLearningServices\preview\2019-09-30\execution.json
  - Microsoft.MachineLearningServices\preview\2019-09-30\modelManagement.json
  - Microsoft.MachineLearningServices\preview\2019-09-30\runHistory.json
  - Microsoft.MachineLearningServices\preview\2019-09-30\datastore.json
  - Microsoft.MachineLearningServices\preview\2019-09-30\artifact.json
  - Microsoft.MachineLearningServices\preview\2019-09-30\hyperdrive.json
```

### Tag: package-2019-08-preview

These settings apply only when `--tag=package-2019-08-preview` is specified on the command line.

``` yaml $(tag) == 'package-2019-08-preview'
input-file:
  - Microsoft.MachineLearningServices/preview/2019-08-01/execution.json
  - Microsoft.MachineLearningServices/preview/2019-08-01/modelManagement.json
  - Microsoft.MachineLearningServices/preview/2019-08-01/runHistory.json
  - Microsoft.MachineLearningServices/preview/2019-08-01/datastore.json
  - Microsoft.MachineLearningServices/preview/2019-08-01/artifact.json
  - Microsoft.MachineLearningServices/preview/2019-08-01/hyperdrive.json
```

---
# Code Generation


## Swagger to SDK

Swagger to SDK has been intentionally disabled for this spec.

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.MachineLearning.Services
  output-folder: $(csharp-sdks-folder)/MachineLearning/Services/Generated
  clear-output-folder: true
```


## Python

Python generation is intentionally disabled.  Please use the published Python package for Azure Machine Learning on PyPi.


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  namespace: com.microsoft.azure.machinelearning.services
  license-header: MICROSOFT_MIT_NO_CODEGEN
  output-folder: $(azure-libraries-for-java-folder)/azure-machinelearning-services
```

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\execution.json
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\modelManagement.json
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\runHistory.json
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\datastore.json
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\artifact.json
  - $(this-folder)/Microsoft.MachineLearningServices\preview\2019-09-30\hyperdrive.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/execution.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/modelManagement.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/runHistory.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/datastore.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/artifact.json
  - $(this-folder)/Microsoft.MachineLearningServices/preview/2019-08-01/hyperdrive.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```

