# Private DNS

> see https://aka.ms/autorest

This is the AutoRest configuration file for Private DNS.

---

## Getting Started

To build the SDK for Private DNS, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the Private DNS API.

``` yaml
openapi-type: arm
tag: package-2020-06
```

### Tag: package-2018-09

These settings apply only when `--tag=package-2018-09` is specified on the command line.

``` yaml $(tag) == 'package-2018-09'
input-file:
  - Microsoft.Network/stable/2018-09-01/privatedns.json
```

### Tag: package-2020-01

These settings apply only when `--tag=package-2020-01` is specified on the command line.

``` yaml $(tag) == 'package-2020-01'
input-file:
  - Microsoft.Network/stable/2020-01-01/privatedns.json
```

### Tag: package-2020-06

These settings apply only when `--tag=package-2020-06` is specified on the command line.

``` yaml $(tag) == 'package-2020-06'
input-file:
  - Microsoft.Network/stable/2020-06-01/privatedns.json
```

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-ruby
  - repo: azure-resource-manager-schemas
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.PrivateDns
  payload-flattening-threshold: 2
  output-folder: $(csharp-sdks-folder)/privatedns/Microsoft.Azure.Management.PrivateDns/src/Generated
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Python

See configuration in [readme.python.md](./readme.python.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.privatedns
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-privatedns
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-09
```

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2020-01
```

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2020-06
```

### Tag: package-2018-09 and java

These settings apply only when `--tag=package-2018-09 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-09' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.privatedns.v2018_09_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/privatedns/mgmt-v2018_09_01
regenerate-manager: true
generate-interface: true
fconfig: '{"moduleName": "privatedns"}'
```

### Tag: package-2020-01 and java

These settings apply only when `--tag=package-2020-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2020-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.privatedns.v2020_01_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/privatedns/mgmt-v2020_01_01
regenerate-manager: true
generate-interface: true
fconfig: '{"moduleName": "privatedns"}'
```

### Tag: package-2020-06 and java

These settings apply only when `--tag=package-2020-06 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2020-06' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.privatedns.v2020_06_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/privatedns/mgmt-v2020_06_01
regenerate-manager: true
generate-interface: true
fconfig: '{"moduleName": "privatedns"}'
```

## Suppression

``` yaml
directive:
  - where: $.paths
    from: privatedns.json
    suppress: OperationsAPIImplementation
    reason: Operation APIs for Microsoft.Network are to be defined in Network swagger.
  - where: $.definitions.VirtualNetworkLinkProperties.properties.registrationEnabled
    from: privatedns.json
    suppress: EnumInsteadOfBoolean
    reason: Booleans are used to indicate binary states of the property, enum is not appropriate.
  - where: $.definitions.RecordSetProperties.properties.isAutoRegistered
    from: privatedns.json
    suppress: EnumInsteadOfBoolean
    reason: Booleans are used to indicate binary states of the property, enum is not appropriate.
  - where: $.definitions
    from: privatedns.json
    suppress: TrackedResourceListByImmediateParent
    reason: Another list API naming approach is used over the specs.
  - where: $.definitions.Resource
    from: types.json
    suppress: DescriptionAndTitleMissing
    reason: Common types warning.
```



