# Quota

> see https://aka.ms/autorest

This is the AutoRest configuration file for Quota RP.

---

## Getting Started

To build the SDK for Quota, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the Quota API.

``` yaml
openapi-type: arm
tag: package-2021-03-15-preview
```

### Tag: package-2021-03-15

These settings apply only when `--tag=package-2021-03-15` is specified on the command line.

```yaml $(tag) == 'package-2021-03-15'
input-file:
  - Microsoft.Quota/stable/2021-03-15/quota.json
```

### Tag: package-021-03-15-preview

These settings apply only when `--tag=package-2021-03-15-preview` is specified on the command line.

```yaml $(tag) == 'package-2021-03-15-preview'
input-file:
  - Microsoft.Quota/preview/2021-03-15-preview/quota.json
```

### Supressions

``` yaml
directive:
- suppress:
    - R3007 # The 'PutGetPatchResponseSchema' Both get and put/Patch is using same data model - CurrentQuotaLimitBase.
    - R4009 # The 'RequiredReadOnlySystemData' It will be added later, if needed.
    - R4018 # The 'OperationsApiResponseSchema' It will be added later, if needed. The current API provides in this format.
```

---
---
# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-cli-extensions
  - repo: azure-sdk-for-ruby
  - repo: azure-resource-manager-schemas
    after_scripts:
      - node sdkauto_afterscript.js quota/resource-manager
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.Quota
  payload-flattening-threshold: 1
  output-folder: $(csharp-sdks-folder)/quota/Microsoft.Azure.Management.Quota/src/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.quota
  package-name: azure-mgmt-quota
  package-version: 0.1.0
  clear-output-folder: true
```

``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/quota/azure-mgmt-quota/azure/mgmt/quota
```

``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/quota/azure-mgmt-quota
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## CLI

See configuration in [readme.cli.md](./readme.cli.md)

## AZ

 See configuration in [readme.az.md](./readme.az.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## AzureResourceSchema

See configuration in [readme.azureresourceschema.md](./readme.azureresourceschema.md)

## Java

See configuration in [readme.java.md](./readme.java.md)

## Ruby

See configuration in [readme.ruby.md](./readme.ruby.md)

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/Microsoft.Quota/preview/2021-03-15-preview/quota.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```
